@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.7001';
+our $VERSION = '0.8';
 
 use warnings;
 use strict;
@@ -206,6 +206,25 @@ sub path_cost {
     return $path_cost;
 }
 
+
+sub dump {
+    my $self = shift;
+    my $attr = shift || 'weight';
+
+    for my $vertex ( sort { $a <=> $b } $self->vertices ) {
+        printf "vertex: %s %s=%.2f\n",
+            $vertex,
+            $attr,
+            $self->get_cost( $vertex, $attr );
+        for my $successor ( sort { $a <=> $b } $self->successors($vertex) ) {
+            printf "\tedge to: %s %s=%.2f\n",
+                $successor,
+                $attr,
+                $self->get_cost( [ $vertex, $successor ], $attr );
+        }
+    }
+}
+
 1;
 
 __END__
@@ -220,7 +239,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.7001
+version 0.8
 
 =head1 SYNOPSIS
 
@@ -235,16 +254,7 @@ version 0.7001
       [ 0,0,0,0,0 ], #    "   4      0 "               0
     ]
  );
- for my $vertex ( sort { $a <=> $b } $gw->vertices ) {
-    printf "vertex: %s weight=%.2f\n",
-        $vertex,
-        $gw->get_cost($vertex);
-    for my $successor ( sort { $a <=> $b } $gw->successors($vertex) ) {
-        printf "\tedge to: %s weight=%.2f\n",
-            $successor,
-            $gw->get_cost( [ $vertex, $successor ] );
-    }
- }
+ $gw->dump();
 
  my ( $lightest, $heaviest ) = $gw->vertex_span;
  ( $lightest, $heaviest ) = $gw->edge_span;
@@ -262,19 +272,7 @@ version 0.7001
     },
     $attr
  );
- for my $vertex ( sort { $a <=> $b } $gw->vertices ) {
-    printf "%s vertex: %s %s=%.2f\n",
-        $gw->get_vertex_attribute( $vertex, 'label' ),
-        $vertex,
-        $attr,
-        $gw->get_cost( $vertex, $attr );
-    for my $successor ( sort { $a <=> $b } $gw->successors($vertex) ) {
-        printf "\tedge to: %s %s=%.2f\n",
-            $successor,
-            $attr,
-            $gw->get_cost( [ $vertex, $successor ], $attr );
-    }
- }
+ $gw->dump($attr);
 
 =head1 DESCRIPTION
 
@@ -333,7 +331,7 @@ Return the lightest and heaviest vertices as array references.
  ($lightest, $heaviest) = $gw->edge_span();
  ($lightest, $heaviest) = $gw->edge_span($attr);
 
-Return the lightest to heaviest edges as array references.
+Return the lightest and heaviest edges as array references.
 
 =head2 path_cost()
 
@@ -345,6 +343,13 @@ Return the summed weight (or cost attribute) of the path edges.
 For the cost of the shortest path, please see C<path_length> under
 L<Graph/"All-Pairs Shortest Paths (APSP)">.
 
+=head2 dump()
+
+  $gw->dump()
+  $gw->dump($attr)
+
+Print out the graph showing vertices, edges and costs.
+
 =head1 EXAMPLES
 
 =head2 Shortest Paths
